@@ -130,7 +130,7 @@ class IterableBody(ResponseBody):
         return self
 
     async def __aexit__(self, exc_type: type, exc_value: BaseException, tb: TracebackType) -> None:
-        pass
+        await self.iter.aclose()
 
     def __aiter__(self) -> AsyncIterator:
         return self.iter
@@ -682,9 +682,7 @@ class Response(_BaseRequestResponse, JSONMixin):
         def on_update(content_security_policy: ContentSecurityPolicy) -> None:
             self.content_security_policy_report_only = content_security_policy
 
-        return ContentSecurityPolicy.from_header(
-            self.headers.get("Content-Security-Policy-Report-Only", ""), on_update
-        )
+        return parse_csp_header(self.headers.get("Content-Security-Policy-Report-Only"), on_update)
 
     @content_security_policy_report_only.setter
     def content_security_policy_report_only(self, value: ContentSecurityPolicy) -> None:
